@@ -94,7 +94,7 @@ context_error(struct context *ctx, int ec, char const *fmt, ...)
 		va_end(ap);
 
 		if (rc) {
-			msg = "out of memory trying to format error mesage";
+			msg = "out of memory trying to format error message";
 			ec = ENOMEM;
 		}
 
